feat(1.88): update patches (#1839)

This commit is contained in:
Baptiste Augrain 2024-04-04 23:14:54 +02:00 committed by GitHub
parent e4b7667390
commit 97bd0850e2
No known key found for this signature in database
GPG Key ID: B5690EEEBB952194
19 changed files with 244 additions and 247 deletions

View File

@ -3,12 +3,15 @@ name: insider-linux
on:
workflow_dispatch:
inputs:
release_version:
type: string
description: Forced release version
force_version:
type: boolean
description: Force update version
generate_assets:
type: boolean
description: Generate assets
checkout_pr:
type: string
description: Checkout PR
repository_dispatch:
types: [insider]
push:
@ -100,6 +103,8 @@ jobs:
if: env.SHOULD_BUILD == 'yes'
- name: Clone VSCode repo
env:
PULL_REQUEST_ID: ${{ github.event.inputs.checkout_pr }}
run: ./get_repo.sh
if: env.SHOULD_BUILD == 'yes'
@ -207,6 +212,7 @@ jobs:
- name: Update versions repo
env:
FORCE_UPDATE: ${{ github.event.inputs.force_version }}
GITHUB_TOKEN: ${{ secrets.STRONGER_GITHUB_TOKEN }}
GITHUB_USERNAME: ${{ github.repository_owner }}
run: ./update_version.sh
@ -252,6 +258,19 @@ jobs:
with:
ref: ${{ env.GITHUB_BRANCH }}
- name: Setup Node.js environment
uses: actions/setup-node@v4
with:
node-version: '18.17'
- name: Setup Python 3
uses: actions/setup-python@v5
with:
python-version: '3.11'
- name: Install libkrb5-dev
run: sudo apt-get install -y libkrb5-dev
- name: Install GH
run: ./install_gh.sh
if: env.SHOULD_DEPLOY == 'yes'

View File

@ -3,12 +3,15 @@ name: insider-macos
on:
workflow_dispatch:
inputs:
release_version:
type: string
description: Forced release version
force_version:
type: boolean
description: Force update version
generate_assets:
type: boolean
description: Generate assets
checkout_pr:
type: string
description: Checkout PR
repository_dispatch:
types: [insider]
push:
@ -56,11 +59,10 @@ jobs:
uses: actions/setup-python@v5
with:
python-version: '3.11'
if: env.VSCODE_ARCH == 'x64'
- name: Clone VSCode repo
env:
RELEASE_VERSION: ${{ github.event.inputs.release_version }}
PULL_REQUEST_ID: ${{ github.event.inputs.checkout_pr }}
run: . get_repo.sh
- name: Check PR or cron
@ -97,6 +99,7 @@ jobs:
- name: Update versions repo
env:
FORCE_UPDATE: ${{ github.event.inputs.force_version }}
GITHUB_TOKEN: ${{ secrets.STRONGER_GITHUB_TOKEN }}
GITHUB_USERNAME: ${{ github.repository_owner }}
run: ./update_version.sh

View File

@ -3,12 +3,15 @@ name: insider-windows
on:
workflow_dispatch:
inputs:
release_version:
type: string
description: Forced release version
force_version:
type: boolean
description: Force update version
generate_assets:
type: boolean
description: Generate assets
checkout_pr:
type: string
description: Checkout PR
repository_dispatch:
types: [insider]
push:
@ -67,7 +70,7 @@ jobs:
- name: Clone VSCode repo
env:
RELEASE_VERSION: ${{ github.event.inputs.release_version }}
PULL_REQUEST_ID: ${{ github.event.inputs.checkout_pr }}
run: ./get_repo.sh
- name: Check PR or cron
@ -102,6 +105,7 @@ jobs:
- name: Update versions repo
env:
FORCE_UPDATE: ${{ github.event.inputs.force_version }}
GITHUB_TOKEN: ${{ secrets.STRONGER_GITHUB_TOKEN }}
GITHUB_USERNAME: ${{ github.repository_owner }}
run: ./update_version.sh

View File

@ -211,6 +211,7 @@ jobs:
- name: Update versions repo
env:
FORCE_UPDATE: ${{ github.event.inputs.force_version }}
GITHUB_TOKEN: ${{ secrets.STRONGER_GITHUB_TOKEN }}
GITHUB_USERNAME: ${{ github.repository_owner }}
run: ./update_version.sh
@ -256,6 +257,19 @@ jobs:
with:
ref: ${{ env.GITHUB_BRANCH }}
- name: Setup Node.js environment
uses: actions/setup-node@v4
with:
node-version: '18.17'
- name: Setup Python 3
uses: actions/setup-python@v5
with:
python-version: '3.11'
- name: Install libkrb5-dev
run: sudo apt-get install -y libkrb5-dev
- name: Install GH
run: ./install_gh.sh
if: env.SHOULD_DEPLOY == 'yes'

View File

@ -9,6 +9,9 @@ on:
generate_assets:
type: boolean
description: Generate assets
checkout_pr:
type: string
description: Checkout PR
repository_dispatch:
types: [stable]
push:
@ -53,9 +56,10 @@ jobs:
uses: actions/setup-python@v5
with:
python-version: '3.11'
if: env.VSCODE_ARCH == 'x64'
- name: Clone VSCode repo
env:
PULL_REQUEST_ID: ${{ github.event.inputs.checkout_pr }}
run: . get_repo.sh
- name: Check PR or cron

View File

@ -9,6 +9,9 @@ on:
generate_assets:
type: boolean
description: Generate assets
checkout_pr:
type: string
description: Checkout PR
repository_dispatch:
types: [stable]
push:
@ -64,6 +67,8 @@ jobs:
python-version: '3.11'
- name: Clone VSCode repo
env:
PULL_REQUEST_ID: ${{ github.event.inputs.checkout_pr }}
run: ./get_repo.sh
- name: Check PR or cron

View File

@ -12,6 +12,8 @@ if [[ "${SHOULD_BUILD}" == "yes" ]]; then
cd vscode || { echo "'vscode' dir not found"; exit 1; }
export NODE_OPTIONS="--max-old-space-size=8192"
yarn monaco-compile-check
yarn valid-layers-check

View File

@ -61,6 +61,8 @@ else
export VSCODE_ARCH="x64"
fi
export NODE_OPTIONS="--max-old-space-size=8192"
echo "OS_NAME=\"${OS_NAME}\""
echo "SKIP_SOURCE=\"${SKIP_SOURCE}\""
echo "SKIP_BUILD=\"${SKIP_BUILD}\""

View File

@ -1,4 +1,4 @@
{
"tag": "1.87.0",
"commit": "019f4d1419fbc8219a181fab7892ebccf7ee29a2"
"tag": "1.88.0",
"commit": "d994aede3529f4d1af9eeaeb234d32fd936243e7"
}

View File

@ -37,7 +37,16 @@ for i in {1..5}; do # try 5 times
echo "Yarn failed $i, trying again..."
done
./build/azure-pipelines/linux/install.sh
./build/azure-pipelines/linux/setup-env.sh
for i in {1..5}; do # try 5 times
yarn --frozen-lockfile --check-files && break
if [ $i -eq 3 ]; then
echo "Yarn failed too many times" >&2
exit 1
fi
echo "Yarn failed $i, trying again..."
done
node build/azure-pipelines/distro/mixin-npm

View File

@ -37,7 +37,16 @@ for i in {1..5}; do # try 5 times
echo "Yarn failed $i, trying again..."
done
./build/azure-pipelines/linux/install.sh
./build/azure-pipelines/linux/setup-env.sh --only-remote
for i in {1..5}; do # try 5 times
yarn --frozen-lockfile --check-files && break
if [ $i -eq 3 ]; then
echo "Yarn failed too many times" >&2
exit 1
fi
echo "Yarn failed $i, trying again..."
done
EXPECTED_GLIBC_VERSION="2.17" EXPECTED_GLIBCXX_VERSION="3.4.22" ./build/azure-pipelines/linux/verify-glibc-requirements.sh

View File

@ -10,10 +10,10 @@ index f791557..04f138d 100644
+ { label: 'workspaceFolderBasename', detail: vscode.l10n.t("The name of the folder opened in VSCodium without any slashes (/)") },
{ label: 'fileWorkspaceFolderBasename', detail: vscode.l10n.t("The current opened file workspace folder name without any slashes (/)") },
diff --git a/extensions/configuration-editing/src/settingsDocumentHelper.ts b/extensions/configuration-editing/src/settingsDocumentHelper.ts
index bbf77e6..28c4142 100644
index 6135df5..484721e 100644
--- a/extensions/configuration-editing/src/settingsDocumentHelper.ts
+++ b/extensions/configuration-editing/src/settingsDocumentHelper.ts
@@ -118,3 +118,3 @@ export class SettingsDocument {
@@ -123,3 +123,3 @@ export class SettingsDocument {
completions.push(this.newSimpleCompletionItem(getText('folderPath'), range, vscode.l10n.t("file path of the workspace folder the file is contained in (e.g. /Users/Development/myFolder)")));
- completions.push(this.newSimpleCompletionItem(getText('appName'), range, vscode.l10n.t("e.g. VS Code")));
+ completions.push(this.newSimpleCompletionItem(getText('appName'), range, vscode.l10n.t("e.g. VSCodium")));
@ -73,37 +73,37 @@ index 8bb2a46..7cee594 100644
+const bumpEngineForImplicitActivationEvents = l10n.t("This activation event can be removed for extensions targeting engine version ^1.75 as VSCodium will generate these automatically from your package.json contribution declarations.");
const starActivation = l10n.t("Using '*' activation is usually a bad idea as it impacts performance.");
diff --git a/extensions/git/package.nls.json b/extensions/git/package.nls.json
index 6eba0f4..dff745a 100644
index 3d0411c..94f6558 100644
--- a/extensions/git/package.nls.json
+++ b/extensions/git/package.nls.json
@@ -214,3 +214,3 @@
@@ -216,3 +216,3 @@
"{Locked='](command:git.showOutput'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -242,4 +242,4 @@
@@ -244,4 +244,4 @@
"config.showCommitInput": "Controls whether to show the commit input in the Git source control panel.",
- "config.terminalAuthentication": "Controls whether to enable VS Code to be the authentication handler for Git processes spawned in the Integrated Terminal. Note: Terminals need to be restarted to pick up a change in this setting.",
- "config.terminalGitEditor": "Controls whether to enable VS Code to be the Git editor for Git processes spawned in the integrated terminal. Note: Terminals need to be restarted to pick up a change in this setting.",
+ "config.terminalAuthentication": "Controls whether to enable VSCodium to be the authentication handler for Git processes spawned in the Integrated Terminal. Note: Terminals need to be restarted to pick up a change in this setting.",
+ "config.terminalGitEditor": "Controls whether to enable VSCodium to be the Git editor for Git processes spawned in the integrated terminal. Note: Terminals need to be restarted to pick up a change in this setting.",
"config.timeline.showAuthor": "Controls whether to show the commit author in the Timeline view.",
@@ -298,3 +298,3 @@
@@ -300,3 +300,3 @@
"{Locked='](command:workbench.action.reloadWindow'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -306,3 +306,3 @@
@@ -308,3 +308,3 @@
"{Locked='](command:workbench.action.reloadWindow'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -314,3 +314,3 @@
@@ -316,3 +316,3 @@
"{Locked='](command:workbench.action.reloadWindow'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -320,6 +320,6 @@
@@ -322,6 +322,6 @@
"view.workbench.scm.disabled": {
- "message": "If you would like to use Git features, please enable Git in your [settings](command:workbench.action.openSettings?%5B%22git.enabled%22%5D).\nTo learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm).",
+ "message": "If you would like to use Git features, please enable Git in your [settings](command:workbench.action.openSettings?%5B%22git.enabled%22%5D).\nTo learn more about how to use Git and source control in VSCodium [read our docs](https://aka.ms/vscode-scm).",
@ -112,7 +112,7 @@ index 6eba0f4..dff745a 100644
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -328,6 +328,6 @@
@@ -330,6 +330,6 @@
"view.workbench.scm.empty": {
- "message": "In order to use Git features, you can open a folder containing a Git repository or clone from a URL.\n[Open Folder](command:vscode.openFolder)\n[Clone Repository](command:git.clone)\nTo learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm).",
+ "message": "In order to use Git features, you can open a folder containing a Git repository or clone from a URL.\n[Open Folder](command:vscode.openFolder)\n[Clone Repository](command:git.clone)\nTo learn more about how to use Git and source control in VSCodium [read our docs](https://aka.ms/vscode-scm).",
@ -121,7 +121,7 @@ index 6eba0f4..dff745a 100644
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -336,6 +336,6 @@
@@ -338,6 +338,6 @@
"view.workbench.scm.folder": {
- "message": "The folder currently open doesn't have a Git repository. You can initialize a repository which will enable source control features powered by Git.\n[Initialize Repository](command:git.init?%5Btrue%5D)\nTo learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm).",
+ "message": "The folder currently open doesn't have a Git repository. You can initialize a repository which will enable source control features powered by Git.\n[Initialize Repository](command:git.init?%5Btrue%5D)\nTo learn more about how to use Git and source control in VSCodium [read our docs](https://aka.ms/vscode-scm).",
@ -130,7 +130,7 @@ index 6eba0f4..dff745a 100644
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -344,6 +344,6 @@
@@ -346,6 +346,6 @@
"view.workbench.scm.workspace": {
- "message": "The workspace currently open doesn't have any folders containing Git repositories. You can initialize a repository on a folder which will enable source control features powered by Git.\n[Initialize Repository](command:git.init)\nTo learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm).",
+ "message": "The workspace currently open doesn't have any folders containing Git repositories. You can initialize a repository on a folder which will enable source control features powered by Git.\n[Initialize Repository](command:git.init)\nTo learn more about how to use Git and source control in VSCodium [read our docs](https://aka.ms/vscode-scm).",
@ -139,7 +139,7 @@ index 6eba0f4..dff745a 100644
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -352,6 +352,6 @@
@@ -354,6 +354,6 @@
"view.workbench.scm.emptyWorkspace": {
- "message": "The workspace currently open doesn't have any folders containing Git repositories.\n[Add Folder to Workspace](command:workbench.action.addRootFolder)\nTo learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm).",
+ "message": "The workspace currently open doesn't have any folders containing Git repositories.\n[Add Folder to Workspace](command:workbench.action.addRootFolder)\nTo learn more about how to use Git and source control in VSCodium [read our docs](https://aka.ms/vscode-scm).",
@ -148,27 +148,27 @@ index 6eba0f4..dff745a 100644
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -370,3 +370,3 @@
@@ -372,3 +372,3 @@
"{Locked='](command:workbench.action.openSettings?%5B%22git.openRepositoryInParentFolders%22%5D'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -379,3 +379,3 @@
@@ -381,3 +381,3 @@
"{Locked='](command:workbench.action.openSettings?%5B%22git.openRepositoryInParentFolders%22%5D'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -387,3 +387,3 @@
@@ -389,3 +389,3 @@
"{Locked='](command:git.manageUnsafeRepositories'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -395,3 +395,3 @@
@@ -397,3 +397,3 @@
"{Locked='](command:git.manageUnsafeRepositories'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -400,6 +400,6 @@
@@ -402,6 +402,6 @@
"view.workbench.scm.closedRepository": {
- "message": "A Git repository was found that was previously closed.\n[Reopen Closed Repository](command:git.reopenClosedRepositories)\nTo learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm).",
+ "message": "A Git repository was found that was previously closed.\n[Reopen Closed Repository](command:git.reopenClosedRepositories)\nTo learn more about how to use Git and source control in VSCodium [read our docs](https://aka.ms/vscode-scm).",
@ -177,7 +177,7 @@ index 6eba0f4..dff745a 100644
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -408,6 +408,6 @@
@@ -410,6 +410,6 @@
"view.workbench.scm.closedRepositories": {
- "message": "Git repositories were found that were previously closed.\n[Reopen Closed Repositories](command:git.reopenClosedRepositories)\nTo learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm).",
+ "message": "Git repositories were found that were previously closed.\n[Reopen Closed Repositories](command:git.reopenClosedRepositories)\nTo learn more about how to use Git and source control in VSCodium [read our docs](https://aka.ms/vscode-scm).",
@ -186,12 +186,12 @@ index 6eba0f4..dff745a 100644
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -419,3 +419,3 @@
@@ -421,3 +421,3 @@
"{Locked='](command:git.clone'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VSCodium",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -423,3 +423,3 @@
@@ -425,3 +425,3 @@
},
- "view.workbench.learnMore": "To learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm)."
+ "view.workbench.learnMore": "To learn more about how to use Git and source control in VSCodium [read our docs](https://aka.ms/vscode-scm)."
@ -282,7 +282,7 @@ index af6c9d8..7057b54 100644
+ "json.tracing.desc": "Traces the communication between VSCodium and the JSON language server.",
"json.colorDecorators.enable.desc": "Enables or disables color decorators",
diff --git a/extensions/markdown-language-features/package.nls.json b/extensions/markdown-language-features/package.nls.json
index af77144..33bbfe5 100644
index a4b2526..088b31e 100644
--- a/extensions/markdown-language-features/package.nls.json
+++ b/extensions/markdown-language-features/package.nls.json
@@ -21,3 +21,3 @@
@ -410,7 +410,7 @@ index 239519e..a308077 100644
+ vscode.window.showErrorMessage(vscode.l10n.t("VSCodium\'s tsserver was deleted by another application such as a misbehaving virus detection tool. Please reinstall VSCodium."));
throw new Error('Could not find bundled tsserver.js');
diff --git a/extensions/typescript-language-features/src/tsconfig.ts b/extensions/typescript-language-features/src/tsconfig.ts
index 196cf18..db942c9 100644
index 04f08a1..2b2b1bb 100644
--- a/extensions/typescript-language-features/src/tsconfig.ts
+++ b/extensions/typescript-language-features/src/tsconfig.ts
@@ -151,3 +151,3 @@ export async function openProjectConfigForFile(
@ -419,7 +419,7 @@ index 196cf18..db942c9 100644
+ vscode.l10n.t("Please open a folder in VSCodium to use a TypeScript or JavaScript project"));
return;
diff --git a/extensions/typescript-language-features/src/typescriptServiceClient.ts b/extensions/typescript-language-features/src/typescriptServiceClient.ts
index 0796bef..f8061fa 100644
index 812a9c4..dad1139 100644
--- a/extensions/typescript-language-features/src/typescriptServiceClient.ts
+++ b/extensions/typescript-language-features/src/typescriptServiceClient.ts
@@ -620,3 +620,3 @@ export default class TypeScriptServiceClient extends Disposable implements IType
@ -434,11 +434,11 @@ index 0796bef..f8061fa 100644
} else {
@@ -655,3 +655,3 @@ export default class TypeScriptServiceClient extends Disposable implements IType
prompt = vscode.window.showWarningMessage<vscode.MessageItem>(
- vscode.l10n.t("The JS/TS language service crashed.\nThis may be caused by a plugin contributed by one of these extensions: {0}.\nPlease try disabling these extensions before filing an issue against VS Code.", pluginExtensionList));
+ vscode.l10n.t("The JS/TS language service crashed.\nThis may be caused by a plugin contributed by one of these extensions: {0}.\nPlease try disabling these extensions before filing an issue against VSCodium.", pluginExtensionList));
- vscode.l10n.t("The JS/TS language service crashed.\nThis may be caused by a plugin contributed by one of these extensions: {0}.\nPlease try disabling these extensions before filing an issue against VS Code.", pluginExtensionList), reportIssueItem);
+ vscode.l10n.t("The JS/TS language service crashed.\nThis may be caused by a plugin contributed by one of these extensions: {0}.\nPlease try disabling these extensions before filing an issue against VSCodium.", pluginExtensionList), reportIssueItem);
} else {
diff --git a/extensions/vscode-api-tests/package.json b/extensions/vscode-api-tests/package.json
index e9323fc..b1435c8 100644
index 1c54b96..542955e 100644
--- a/extensions/vscode-api-tests/package.json
+++ b/extensions/vscode-api-tests/package.json
@@ -2,3 +2,3 @@
@ -516,19 +516,19 @@ index fa001b5..13abac2 100644
+ throw Error(`Failed to download and unzip VSCodium ${quality} - ${commit}`);
}
diff --git a/src/vs/code/electron-main/app.ts b/src/vs/code/electron-main/app.ts
index 7a03905..6995020 100644
index 578b00a..5472f5b 100644
--- a/src/vs/code/electron-main/app.ts
+++ b/src/vs/code/electron-main/app.ts
@@ -568,3 +568,3 @@ export class CodeApplication extends Disposable {
@@ -571,3 +571,3 @@ export class CodeApplication extends Disposable {
async startup(): Promise<void> {
- this.logService.debug('Starting VS Code');
+ this.logService.debug('Starting VSCodium');
this.logService.debug(`from: ${this.environmentMainService.appRoot}`);
diff --git a/src/vs/code/electron-sandbox/issue/issueReporterService.ts b/src/vs/code/electron-sandbox/issue/issueReporterService.ts
index 067f09f..6684119 100644
index ac9f828..089f04c 100644
--- a/src/vs/code/electron-sandbox/issue/issueReporterService.ts
+++ b/src/vs/code/electron-sandbox/issue/issueReporterService.ts
@@ -817,3 +817,3 @@ export class IssueReporter extends Disposable {
@@ -855,3 +855,3 @@ export class IssueReporter extends Disposable {
hide(descriptionTextArea);
- reset(descriptionTitle, localize('handlesIssuesElsewhere', "This extension handles issues outside of VS Code"));
+ reset(descriptionTitle, localize('handlesIssuesElsewhere', "This extension handles issues outside of VSCodium"));
@ -552,31 +552,31 @@ index 296245b..cf03674 100644
+export const ProductQualityContext = new RawContextKey<string>('productQualityType', '', localize('productQualityType', "Quality type of VSCodium"));
diff --git a/src/vs/platform/extensionManagement/node/extensionManagementService.ts b/src/vs/platform/extensionManagement/node/extensionManagementService.ts
index 217d772..09022c8 100644
index 56e32e7..49a56bb 100644
--- a/src/vs/platform/extensionManagement/node/extensionManagementService.ts
+++ b/src/vs/platform/extensionManagement/node/extensionManagementService.ts
@@ -151,3 +151,3 @@ export class ExtensionManagementService extends AbstractExtensionManagementServi
@@ -152,3 +152,3 @@ export class ExtensionManagementService extends AbstractExtensionManagementServi
if (manifest.engines && manifest.engines.vscode && !isEngineValid(manifest.engines.vscode, this.productService.version, this.productService.date)) {
- throw new Error(nls.localize('incompatible', "Unable to install extension '{0}' as it is not compatible with VS Code '{1}'.", extensionId, this.productService.version));
+ throw new Error(nls.localize('incompatible', "Unable to install extension '{0}' as it is not compatible with VSCodium '{1}'.", extensionId, this.productService.version));
}
@@ -228,3 +228,3 @@ export class ExtensionManagementService extends AbstractExtensionManagementServi
@@ -229,3 +229,3 @@ export class ExtensionManagementService extends AbstractExtensionManagementServi
} catch (e) {
- throw new Error(nls.localize('removeError', "Error while removing the extension: {0}. Please Quit and Start VS Code before trying again.", toErrorMessage(e)));
+ throw new Error(nls.localize('removeError', "Error while removing the extension: {0}. Please Quit and Start VSCodium before trying again.", toErrorMessage(e)));
}
@@ -987,3 +987,3 @@ class InstallVSIXTask extends InstallExtensionTask {
@@ -1029,3 +1029,3 @@ class InstallVSIXTask extends InstallExtensionTask {
} catch (e) {
- throw new Error(nls.localize('restartCode', "Please restart VS Code before reinstalling {0}.", this.manifest.displayName || this.manifest.name));
+ throw new Error(nls.localize('restartCode', "Please restart VSCodium before reinstalling {0}.", this.manifest.displayName || this.manifest.name));
}
@@ -1000,3 +1000,3 @@ class InstallVSIXTask extends InstallExtensionTask {
@@ -1042,3 +1042,3 @@ class InstallVSIXTask extends InstallExtensionTask {
} catch (e) {
- throw new Error(nls.localize('restartCode', "Please restart VS Code before reinstalling {0}.", this.manifest.displayName || this.manifest.name));
+ throw new Error(nls.localize('restartCode', "Please restart VSCodium before reinstalling {0}.", this.manifest.displayName || this.manifest.name));
}
diff --git a/src/vs/platform/externalTerminal/node/externalTerminalService.ts b/src/vs/platform/externalTerminal/node/externalTerminalService.ts
index a8df823..8318b2f 100644
index 5086c95..2e424b7 100644
--- a/src/vs/platform/externalTerminal/node/externalTerminalService.ts
+++ b/src/vs/platform/externalTerminal/node/externalTerminalService.ts
@@ -17,3 +17,3 @@ import { ITerminalEnvironment } from 'vs/platform/terminal/common/terminal';
@ -612,10 +612,10 @@ index 39e65d4..acb03b1 100644
+ comment: 'This is used to understand how often VSCodium pings the update server for an update and there\'s none available.';
};
diff --git a/src/vs/platform/update/electron-main/updateService.darwin.ts b/src/vs/platform/update/electron-main/updateService.darwin.ts
index 329488a..c77219d 100644
index 183c69d..2da152d 100644
--- a/src/vs/platform/update/electron-main/updateService.darwin.ts
+++ b/src/vs/platform/update/electron-main/updateService.darwin.ts
@@ -113,4 +113,4 @@ export class DarwinUpdateService extends AbstractUpdateService implements IRelau
@@ -115,4 +115,4 @@ export class DarwinUpdateService extends AbstractUpdateService implements IRelau
owner: 'joaomoreno';
- version: { classification: 'SystemMetaData'; purpose: 'FeatureInsight'; comment: 'The version number of the new VS Code that has been downloaded.' };
- comment: 'This is used to know how often VS Code has successfully downloaded the update.';
@ -668,10 +668,10 @@ index 806a6b6..3ea5aa5 100644
+ test('Opening a notebook results in VSCodium firing the event onDidChangeActiveNotebookEditor twice #118470', function () {
let count = 0;
diff --git a/src/vs/workbench/browser/workbench.contribution.ts b/src/vs/workbench/browser/workbench.contribution.ts
index b715436..ea90812 100644
index 8f88583..8d03b04 100644
--- a/src/vs/workbench/browser/workbench.contribution.ts
+++ b/src/vs/workbench/browser/workbench.contribution.ts
@@ -610,3 +610,3 @@ const registry = Registry.as<IConfigurationRegistry>(ConfigurationExtensions.Con
@@ -640,3 +640,3 @@ const registry = Registry.as<IConfigurationRegistry>(ConfigurationExtensions.Con
localize('profileName', "`${profileName}`: name of the profile in which the workspace is opened (e.g. Data Science (Profile)). Ignored if default profile is used."),
- localize('appName', "`${appName}`: e.g. VS Code."),
+ localize('appName', "`${appName}`: e.g. VSCodium."),
@ -686,127 +686,82 @@ index 4233162..9bd6599 100644
+ description: nls.localize('debugServer', "For debug extension development only: if a port is specified VSCodium tries to connect to a debug adapter running in server mode"),
default: 4711
diff --git a/src/vs/workbench/contrib/extensions/browser/extensions.contribution.ts b/src/vs/workbench/contrib/extensions/browser/extensions.contribution.ts
index c2747ac..4270375 100644
index d7783e5..30d795c 100644
--- a/src/vs/workbench/contrib/extensions/browser/extensions.contribution.ts
+++ b/src/vs/workbench/contrib/extensions/browser/extensions.contribution.ts
@@ -300,3 +300,3 @@ CommandsRegistry.registerCommand({
@@ -302,3 +302,3 @@ CommandsRegistry.registerCommand({
description: '(optional) Options for installing the extension. Object with the following properties: ' +
- '`installOnlyNewlyAddedFromExtensionPackVSIX`: When enabled, VS Code installs only newly added extensions from the extension pack VSIX. This option is considered only when installing VSIX. ',
+ '`installOnlyNewlyAddedFromExtensionPackVSIX`: When enabled, VSCodium installs only newly added extensions from the extension pack VSIX. This option is considered only when installing VSIX. ',
isOptional: true,
@@ -307,3 +307,3 @@ CommandsRegistry.registerCommand({
@@ -309,3 +309,3 @@ CommandsRegistry.registerCommand({
'type': 'boolean',
- 'description': localize('workbench.extensions.installExtension.option.installOnlyNewlyAddedFromExtensionPackVSIX', "When enabled, VS Code installs only newly added extensions from the extension pack VSIX. This option is considered only while installing a VSIX."),
+ 'description': localize('workbench.extensions.installExtension.option.installOnlyNewlyAddedFromExtensionPackVSIX', "When enabled, VSCodium installs only newly added extensions from the extension pack VSIX. This option is considered only while installing a VSIX."),
default: false
@@ -312,3 +312,3 @@ CommandsRegistry.registerCommand({
@@ -314,3 +314,3 @@ CommandsRegistry.registerCommand({
'type': 'boolean',
- 'description': localize('workbench.extensions.installExtension.option.installPreReleaseVersion', "When enabled, VS Code installs the pre-release version of the extension if available."),
+ 'description': localize('workbench.extensions.installExtension.option.installPreReleaseVersion', "When enabled, VSCodium installs the pre-release version of the extension if available."),
default: false
@@ -317,3 +317,3 @@ CommandsRegistry.registerCommand({
@@ -319,3 +319,3 @@ CommandsRegistry.registerCommand({
'type': 'boolean',
- 'description': localize('workbench.extensions.installExtension.option.donotSync', "When enabled, VS Code do not sync this extension when Settings Sync is on."),
+ 'description': localize('workbench.extensions.installExtension.option.donotSync', "When enabled, VSCodium do not sync this extension when Settings Sync is on."),
default: false
@@ -841,3 +841,3 @@ class ExtensionsContributions extends Disposable implements IWorkbenchContributi
@@ -865,3 +865,3 @@ class ExtensionsContributions extends Disposable implements IWorkbenchContributi
const requireReload = !(extension.local && extensionService.canAddExtension(toExtensionDescription(extension.local)));
- const message = requireReload ? localize('InstallVSIXAction.successReload', "Completed installing {0} extension from VSIX. Please reload Visual Studio Code to enable it.", extension.displayName || extension.name)
+ const message = requireReload ? localize('InstallVSIXAction.successReload', "Completed installing {0} extension from VSIX. Please reload VSCodium to enable it.", extension.displayName || extension.name)
: localize('InstallVSIXAction.success', "Completed installing {0} extension from VSIX.", extension.displayName || extension.name);
diff --git a/src/vs/workbench/contrib/extensions/browser/extensionsActions.ts b/src/vs/workbench/contrib/extensions/browser/extensionsActions.ts
index 1fc58a9..8fff128 100644
index ac83a64..c809884 100644
--- a/src/vs/workbench/contrib/extensions/browser/extensionsActions.ts
+++ b/src/vs/workbench/contrib/extensions/browser/extensionsActions.ts
@@ -105,3 +105,3 @@ export class PromptExtensionInstallFailureAction extends Action {
@@ -106,3 +106,3 @@ export class PromptExtensionInstallFailureAction extends Action {
if (this.error.name === ExtensionManagementErrorCode.Unsupported) {
- const productName = isWeb ? localize('VS Code for Web', "{0} for the Web", this.productService.nameLong) : this.productService.nameLong;
+ const productName = isWeb ? localize('VSCodium for Web', "{0} for the Web", this.productService.nameLong) : this.productService.nameLong;
const message = localize('cannot be installed', "The '{0}' extension is not available in {1}. Click 'More Information' to learn more.", this.extension.displayName || this.extension.identifier.id, productName);
@@ -385,3 +385,3 @@ export class InstallAction extends ExtensionAction {
@@ -387,3 +387,3 @@ export class InstallAction extends ExtensionAction {
} else if (this.extension.deprecationInfo.settings) {
- detail = localize('deprecated with alternate settings message', "This extension is deprecated as this functionality is now built-in to VS Code.");
+ detail = localize('deprecated with alternate settings message', "This extension is deprecated as this functionality is now built-in to VSCodium.");
@@ -770,3 +770,3 @@ export class UninstallAction extends ExtensionAction {
@@ -775,3 +775,3 @@ export class UninstallAction extends ExtensionAction {
await this.extensionsWorkbenchService.uninstall(this.extension);
- alert(localize('uninstallExtensionComplete', "Please reload Visual Studio Code to complete the uninstallation of the extension {0}.", this.extension.displayName));
+ alert(localize('uninstallExtensionComplete', "Please reload VSCodium to complete the uninstallation of the extension {0}.", this.extension.displayName));
} catch (error) {
@@ -2320,3 +2320,3 @@ export class ExtensionStatusAction extends ExtensionAction {
@@ -2381,3 +2381,3 @@ export class ExtensionStatusAction extends ExtensionAction {
const link = `[${localize('settings', "settings")}](${URI.parse(`command:workbench.action.openSettings?${encodeURIComponent(JSON.stringify([this.extension.deprecationInfo.settings.map(setting => `@id:${setting}`).join(' ')]))}`)})`;
- this.updateStatus({ icon: warningIcon, message: new MarkdownString(localize('deprecated with alternate settings tooltip', "This extension is deprecated as this functionality is now built-in to VS Code. Configure these {0} to use this functionality.", link)) }, true);
+ this.updateStatus({ icon: warningIcon, message: new MarkdownString(localize('deprecated with alternate settings tooltip', "This extension is deprecated as this functionality is now built-in to VSCodium. Configure these {0} to use this functionality.", link)) }, true);
} else {
@@ -2344,3 +2344,3 @@ export class ExtensionStatusAction extends ExtensionAction {
@@ -2405,3 +2405,3 @@ export class ExtensionStatusAction extends ExtensionAction {
if (this.extensionManagementServerService.webExtensionManagementServer) {
- const productName = localize('VS Code for Web', "{0} for the Web", this.productService.nameLong);
+ const productName = localize('VSCodium for Web', "{0} for the Web", this.productService.nameLong);
const message = new MarkdownString(`${localize('not web tooltip', "The '{0}' extension is not available in {1}.", this.extension.displayName || this.extension.identifier.id, productName)} [${localize('learn why', "Learn Why")}](https://aka.ms/vscode-web-extensions-guide)`);
@@ -2621,3 +2621,3 @@ export class ReinstallAction extends Action {
@@ -2682,3 +2682,3 @@ export class ReinstallAction extends Action {
const requireReload = !(extension.local && this.extensionService.canAddExtension(toExtensionDescription(extension.local)));
- const message = requireReload ? localize('ReinstallAction.successReload', "Please reload Visual Studio Code to complete reinstalling the extension {0}.", extension.identifier.id)
+ const message = requireReload ? localize('ReinstallAction.successReload', "Please reload VSCodium to complete reinstalling the extension {0}.", extension.identifier.id)
: localize('ReinstallAction.success', "Reinstalling the extension {0} is completed.", extension.identifier.id);
diff --git a/src/vs/workbench/contrib/extensions/common/extensionsFileTemplate.ts b/src/vs/workbench/contrib/extensions/common/extensionsFileTemplate.ts
index 3e8cd71..6142f61 100644
--- a/src/vs/workbench/contrib/extensions/common/extensionsFileTemplate.ts
@ -868,7 +823,7 @@ index 50ed5aa..a28e184 100644
+ `// ${nls.localize('doc', 'Open VSCodium and run "Developer: Inspect Key Mappings (JSON)" from Command Palette.')}`,
``,
diff --git a/src/vs/workbench/contrib/remoteTunnel/electron-sandbox/remoteTunnel.contribution.ts b/src/vs/workbench/contrib/remoteTunnel/electron-sandbox/remoteTunnel.contribution.ts
index 305f9ba..f4f2ee2 100644
index 0f75017..2736bfe 100644
--- a/src/vs/workbench/contrib/remoteTunnel/electron-sandbox/remoteTunnel.contribution.ts
+++ b/src/vs/workbench/contrib/remoteTunnel/electron-sandbox/remoteTunnel.contribution.ts
@@ -559,3 +559,3 @@ export class RemoteTunnelWorkbenchContribution extends Disposable implements IWo
@ -886,10 +841,10 @@ index b24d91f..a098a62 100644
+ const message = await this.tasExperimentService?.getTreatment<string>('CESSurveyMessage') ?? nls.localize('cesSurveyQuestion', 'Got a moment to help the VSCodium team? Please tell us about your experience with VSCodium so far.');
const button = await this.tasExperimentService?.getTreatment<string>('CESSurveyButton') ?? nls.localize('giveFeedback', "Give Feedback");
diff --git a/src/vs/workbench/contrib/tasks/browser/abstractTaskService.ts b/src/vs/workbench/contrib/tasks/browser/abstractTaskService.ts
index 4324666..e7a7de6 100644
index 5605c99..703e78b 100644
--- a/src/vs/workbench/contrib/tasks/browser/abstractTaskService.ts
+++ b/src/vs/workbench/contrib/tasks/browser/abstractTaskService.ts
@@ -3164,3 +3164,3 @@ export abstract class AbstractTaskService extends Disposable implements ITaskSer
@@ -3167,3 +3167,3 @@ export abstract class AbstractTaskService extends Disposable implements ITaskSer
if (response.code && response.code === TerminateResponseCode.ProcessNotFound) {
- this._notificationService.error(nls.localize('TerminateAction.noProcess', 'The launched process doesn\'t exist anymore. If the task spawned background tasks exiting VS Code might result in orphaned processes.'));
+ this._notificationService.error(nls.localize('TerminateAction.noProcess', 'The launched process doesn\'t exist anymore. If the task spawned background tasks exiting VSCodium might result in orphaned processes.'));
@ -927,7 +882,7 @@ index 9efbc2a..18c7aec 100644
+ message: nls.localize('TaskSystem.noProcess', 'The launched task doesn\'t exist anymore. If the task spawned background processes exiting VSCodium might result in orphaned processes. To avoid this start the last background process with a wait flag.'),
primaryButton: nls.localize({ key: 'TaskSystem.exitAnyways', comment: ['&& denotes a mnemonic'] }, "&&Exit Anyways"),
diff --git a/src/vs/workbench/contrib/terminal/browser/terminalView.ts b/src/vs/workbench/contrib/terminal/browser/terminalView.ts
index 31ed968..cb9501a 100644
index 7bf4f42..2a1d39e 100644
--- a/src/vs/workbench/contrib/terminal/browser/terminalView.ts
+++ b/src/vs/workbench/contrib/terminal/browser/terminalView.ts
@@ -199,3 +199,3 @@ export class TerminalViewPane extends ViewPane {
@ -936,7 +891,7 @@ index 31ed968..cb9501a 100644
+ this._notificationService.prompt(Severity.Warning, nls.localize('terminal.monospaceOnly', "The terminal only supports monospace fonts. Be sure to restart VSCodium if this is a newly installed font."), choices);
}
diff --git a/src/vs/workbench/contrib/terminal/common/terminalConfiguration.ts b/src/vs/workbench/contrib/terminal/common/terminalConfiguration.ts
index 0df9dc1..2b7e952 100644
index bdc76cd..72bb5ce 100644
--- a/src/vs/workbench/contrib/terminal/common/terminalConfiguration.ts
+++ b/src/vs/workbench/contrib/terminal/common/terminalConfiguration.ts
@@ -286,3 +286,3 @@ const terminalConfiguration: IConfigurationNode = {
@ -974,12 +929,12 @@ index 0df9dc1..2b7e952 100644
- markdownDescription: localize('terminal.integrated.env.windows', "Object with environment variables that will be added to the VS Code process to be used by the terminal on Windows. Set to `null` to delete the environment variable."),
+ markdownDescription: localize('terminal.integrated.env.windows', "Object with environment variables that will be added to the VSCodium process to be used by the terminal on Windows. Set to `null` to delete the environment variable."),
type: 'object',
@@ -563,3 +563,3 @@ const terminalConfiguration: IConfigurationNode = {
@@ -568,3 +568,3 @@ const terminalConfiguration: IConfigurationNode = {
[TerminalSettingId.AutoReplies]: {
- markdownDescription: localize('terminal.integrated.autoReplies', "A set of messages that, when encountered in the terminal, will be automatically responded to. Provided the message is specific enough, this can help automate away common responses.\n\nRemarks:\n\n- Use {0} to automatically respond to the terminate batch job prompt on Windows.\n- The message includes escape sequences so the reply might not happen with styled text.\n- Each reply can only happen once every second.\n- Use {1} in the reply to mean the enter key.\n- To unset a default key, set the value to null.\n- Restart VS Code if new don't apply.", '`"Terminate batch job (Y/N)": "Y\\r"`', '`"\\r"`'),
+ markdownDescription: localize('terminal.integrated.autoReplies', "A set of messages that, when encountered in the terminal, will be automatically responded to. Provided the message is specific enough, this can help automate away common responses.\n\nRemarks:\n\n- Use {0} to automatically respond to the terminate batch job prompt on Windows.\n- The message includes escape sequences so the reply might not happen with styled text.\n- Each reply can only happen once every second.\n- Use {1} in the reply to mean the enter key.\n- To unset a default key, set the value to null.\n- Restart VSCodium if new don't apply.", '`"Terminate batch job (Y/N)": "Y\\r"`', '`"\\r"`'),
type: 'object',
@@ -576,3 +576,3 @@ const terminalConfiguration: IConfigurationNode = {
@@ -581,3 +581,3 @@ const terminalConfiguration: IConfigurationNode = {
restricted: true,
- markdownDescription: localize('terminal.integrated.shellIntegration.enabled', "Determines whether or not shell integration is auto-injected to support features like enhanced command tracking and current working directory detection. \n\nShell integration works by injecting the shell with a startup script. The script gives VS Code insight into what is happening within the terminal.\n\nSupported shells:\n\n- Linux/macOS: bash, fish, pwsh, zsh\n - Windows: pwsh\n\nThis setting applies only when terminals are created, so you will need to restart your terminals for it to take effect.\n\n Note that the script injection may not work if you have custom arguments defined in the terminal profile, have enabled {1}, have a [complex bash `PROMPT_COMMAND`](https://code.visualstudio.com/docs/editor/integrated-terminal#_complex-bash-promptcommand), or other unsupported setup. To disable decorations, see {0}", '`#terminal.integrated.shellIntegrations.decorationsEnabled#`', '`#editor.accessibilitySupport#`'),
+ markdownDescription: localize('terminal.integrated.shellIntegration.enabled', "Determines whether or not shell integration is auto-injected to support features like enhanced command tracking and current working directory detection. \n\nShell integration works by injecting the shell with a startup script. The script gives VSCodium insight into what is happening within the terminal.\n\nSupported shells:\n\n- Linux/macOS: bash, fish, pwsh, zsh\n - Windows: pwsh\n\nThis setting applies only when terminals are created, so you will need to restart your terminals for it to take effect.\n\n Note that the script injection may not work if you have custom arguments defined in the terminal profile, have enabled {1}, have a [complex bash `PROMPT_COMMAND`](https://code.visualstudio.com/docs/editor/integrated-terminal#_complex-bash-promptcommand), or other unsupported setup. To disable decorations, see {0}", '`#terminal.integrated.shellIntegrations.decorationsEnabled#`', '`#editor.accessibilitySupport#`'),
@ -999,17 +954,17 @@ index 2117ec5..6ad1388 100644
+ localize({ key: 'newThemeNotification', comment: ['{0} is the name of the new default theme'] }, "VSCodium now ships with a new default theme '{0}'. Do you want to give it a try?", theme.label),
choices,
diff --git a/src/vs/workbench/contrib/update/browser/update.ts b/src/vs/workbench/contrib/update/browser/update.ts
index 969c563..772e061 100644
index af1b3d5..7b06e7a 100644
--- a/src/vs/workbench/contrib/update/browser/update.ts
+++ b/src/vs/workbench/contrib/update/browser/update.ts
@@ -555,4 +555,4 @@ export class SwitchProductQualityContribution extends Disposable implements IWor
@@ -579,4 +579,4 @@ export class SwitchProductQualityContribution extends Disposable implements IWor
detail: newQuality === 'insider' ?
- nls.localize('relaunchDetailInsiders', "Press the reload button to switch to the Insiders version of VS Code.") :
- nls.localize('relaunchDetailStable', "Press the reload button to switch to the Stable version of VS Code."),
+ nls.localize('relaunchDetailInsiders', "Press the reload button to switch to the Insiders version of VSCodium.") :
+ nls.localize('relaunchDetailStable', "Press the reload button to switch to the Stable version of VSCodium."),
primaryButton: nls.localize({ key: 'reload', comment: ['&& denotes a mnemonic'] }, "&&Reload")
@@ -591,3 +591,3 @@ export class SwitchProductQualityContribution extends Disposable implements IWor
@@ -615,3 +615,3 @@ export class SwitchProductQualityContribution extends Disposable implements IWor
message: nls.localize('selectSyncService.message', "Choose the settings sync service to use after changing the version"),
- detail: nls.localize('selectSyncService.detail', "The Insiders version of VS Code will synchronize your settings, keybindings, extensions, snippets and UI State using separate insiders settings sync service by default."),
+ detail: nls.localize('selectSyncService.detail', "The Insiders version of VSCodium will synchronize your settings, keybindings, extensions, snippets and UI State using separate insiders settings sync service by default."),
@ -1029,7 +984,7 @@ index c5c2258..fb5045b 100644
+ content += `// By default, VSCodium trusts "localhost".\n`;
}
diff --git a/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.contribution.ts b/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.contribution.ts
index fc6c589..bc6c802 100644
index 66b9062..18a2219 100644
--- a/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.contribution.ts
+++ b/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.contribution.ts
@@ -321,3 +321,3 @@ configurationRegistry.registerConfiguration({
@ -1180,19 +1135,19 @@ index f1e76e5..275ad1a 100644
+ description: localize('argv.useInMemorySecretStorage', "Ensures that an in-memory store will be used for secret storage instead of using the OS's credential store. This is often used when running VSCodium extension tests or when you're experiencing difficulties with the credential store.")
}
diff --git a/src/vs/workbench/services/extensionManagement/common/extensionManagementService.ts b/src/vs/workbench/services/extensionManagement/common/extensionManagementService.ts
index 5dcc2ff..8b02544 100644
index a22a4d5..e59d9e8 100644
--- a/src/vs/workbench/services/extensionManagement/common/extensionManagementService.ts
+++ b/src/vs/workbench/services/extensionManagement/common/extensionManagementService.ts
@@ -492,3 +492,3 @@ export class ExtensionManagementService extends Disposable implements IWorkbench
@@ -714,3 +714,3 @@ export class ExtensionManagementService extends Disposable implements IWorkbench
- const productName = localize('VS Code for Web', "{0} for the Web", this.productService.nameLong);
+ const productName = localize('VSCodium for Web', "{0} for the Web", this.productService.nameLong);
const virtualWorkspaceSupport = this.extensionManifestPropertiesService.getExtensionVirtualWorkspaceSupportType(manifest);
diff --git a/src/vs/workbench/services/extensions/browser/extensionUrlHandler.ts b/src/vs/workbench/services/extensions/browser/extensionUrlHandler.ts
index d019d14..2000419 100644
index 65672a1..062933d 100644
--- a/src/vs/workbench/services/extensions/browser/extensionUrlHandler.ts
+++ b/src/vs/workbench/services/extensions/browser/extensionUrlHandler.ts
@@ -88,3 +88,3 @@ type ExtensionUrlHandlerClassification = {
@@ -86,3 +86,3 @@ type ExtensionUrlHandlerClassification = {
readonly extensionId: { classification: 'PublicNonPersonalData'; purpose: 'FeatureInsight'; comment: 'The ID of the extension that should handle the URI' };
- comment: 'This is used to understand the drop funnel of extension URI handling by the OS & VS Code.';
+ comment: 'This is used to understand the drop funnel of extension URI handling by the OS & VSCodium.';

View File

@ -1,5 +1,5 @@
diff --git a/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.contribution.ts b/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.contribution.ts
index fc6c589..ed0df30 100644
index 66b9062..0a659dc 100644
--- a/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.contribution.ts
+++ b/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.contribution.ts
@@ -315,2 +315,8 @@ configurationRegistry.registerConfiguration({
@ -12,10 +12,10 @@ index fc6c589..ed0df30 100644
+ },
'workbench.startupEditor': {
diff --git a/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.ts b/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.ts
index 99d6a26..b42713d 100644
index a73549a..fc95016 100644
--- a/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.ts
+++ b/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.ts
@@ -114,4 +114,8 @@ type GettingStartedActionEvent = {
@@ -115,4 +115,8 @@ type GettingStartedActionEvent = {
type RecentEntry = (IRecentFolder | IRecentWorkspace) & { id: string };
+type AnnouncementEntry = { id: string, title: string, url: string };
@ -24,26 +24,35 @@ index 99d6a26..b42713d 100644
+const BUILTIN_ANNOUNCEMENTS: AnnouncementEntry[] = [/* BUILTIN_ANNOUNCEMENTS */];
+
export class GettingStartedPage extends EditorPane {
@@ -150,2 +154,4 @@ export class GettingStartedPage extends EditorPane {
@@ -151,2 +155,4 @@ export class GettingStartedPage extends EditorPane {
private gettingStartedList?: GettingStartedIndexList<IResolvedWalkthrough>;
+ private announcementList?: GettingStartedIndexList<AnnouncementEntry>;
+ private announcementData?: AnnouncementEntry[];
@@ -809,2 +815,3 @@ export class GettingStartedPage extends EditorPane {
private videoList?: GettingStartedIndexList<IWelcomePageStartEntry>;
@@ -844,2 +850,3 @@ export class GettingStartedPage extends EditorPane {
const gettingStartedList = this.buildGettingStartedWalkthroughsList();
+ const announcementList = await this.buildAnnouncementList();
@@ -819,3 +826,3 @@ export class GettingStartedPage extends EditorPane {
this.container.classList.remove('noWalkthroughs');
- reset(rightColumn, gettingStartedList.getDomElement());
+ reset(rightColumn, gettingStartedList.getDomElement(), announcementList.getDomElement());
}
@@ -823,3 +830,3 @@ export class GettingStartedPage extends EditorPane {
this.container.classList.add('noWalkthroughs');
- reset(rightColumn);
+ reset(rightColumn, announcementList.getDomElement());
@@ -976,2 +983,55 @@ export class GettingStartedPage extends EditorPane {
@@ -856,6 +863,6 @@ export class GettingStartedPage extends EditorPane {
this.container.classList.remove('noVideos');
- reset(rightColumn, videoList?.getDomElement(), gettingStartedList.getDomElement());
+ reset(rightColumn, videoList?.getDomElement(), gettingStartedList.getDomElement(), announcementList.getDomElement());
} else {
this.container.classList.add('noVideos');
- reset(rightColumn, gettingStartedList.getDomElement());
+ reset(rightColumn, gettingStartedList.getDomElement(), announcementList.getDomElement());
}
@@ -866,3 +873,3 @@ export class GettingStartedPage extends EditorPane {
this.container.classList.remove('noVideos');
- reset(rightColumn, videoList?.getDomElement());
+ reset(rightColumn, videoList?.getDomElement(), announcementList.getDomElement());
}
@@ -870,3 +877,3 @@ export class GettingStartedPage extends EditorPane {
this.container.classList.add('noVideos');
- reset(rightColumn);
+ reset(rightColumn, announcementList.getDomElement());
}
@@ -1023,2 +1030,55 @@ export class GettingStartedPage extends EditorPane {
+ private async buildAnnouncementList(): Promise<GettingStartedIndexList<AnnouncementEntry>> {
+ const renderAnnouncement = (announcement: AnnouncementEntry) => {

View File

@ -19,21 +19,21 @@ index 8c2b62f..843e8d4 100644
+ const buildRpmTask = task.define(`vscode-linux-${arch}-build-rpm`, task.series(prepareRpmTask, buildRpmPackage(arch)));
gulp.task(buildRpmTask);
diff --git a/build/linux/dependencies-generator.js b/build/linux/dependencies-generator.js
index e40ed70..3e7dbc9 100644
index 80c247d..40f1df2 100644
--- a/build/linux/dependencies-generator.js
+++ b/build/linux/dependencies-generator.js
@@ -24,3 +24,3 @@ const product = require("../../product.json");
// are valid, are in dep-lists.ts
-const FAIL_BUILD_FOR_NEW_DEPENDENCIES = true;
+const FAIL_BUILD_FOR_NEW_DEPENDENCIES = false;
// Based on https://source.chromium.org/chromium/chromium/src/+/refs/tags/118.0.5993.159:chrome/installer/linux/BUILD.gn;l=64-80
// Based on https://source.chromium.org/chromium/chromium/src/+/refs/tags/120.0.6099.268:chrome/installer/linux/BUILD.gn;l=64-80
@@ -56,3 +56,3 @@ async function getDependencies(packageType, buildDir, applicationName, arch) {
// Add the tunnel binary.
- files.push(path.join(buildDir, 'bin', product.tunnelApplicationName));
+ // files.push(path.join(buildDir, 'bin', product.tunnelApplicationName));
// Add the main executable.
diff --git a/build/linux/dependencies-generator.ts b/build/linux/dependencies-generator.ts
index 12bc3c0..4c3a4ac 100644
index 9f1a068..48e3d52 100644
--- a/build/linux/dependencies-generator.ts
+++ b/build/linux/dependencies-generator.ts
@@ -25,3 +25,3 @@ import product = require('../../product.json');

View File

@ -1,5 +1,5 @@
diff --git a/src/vs/workbench/browser/parts/banner/bannerPart.ts b/src/vs/workbench/browser/parts/banner/bannerPart.ts
index b522e75..5205e2b 100644
index dda7c88..e01f09e 100644
--- a/src/vs/workbench/browser/parts/banner/bannerPart.ts
+++ b/src/vs/workbench/browser/parts/banner/bannerPart.ts
@@ -11,3 +11,3 @@ import { InstantiationType, registerSingleton } from 'vs/platform/instantiation/
@ -31,7 +31,7 @@ index b522e75..5205e2b 100644
+ }
+
// Clear previous item
@@ -236,2 +249,15 @@ export class BannerPart extends Part implements IBannerService {
@@ -235,2 +248,15 @@ export class BannerPart extends Part implements IBannerService {
+ private toStorageScope(options: INeverShowAgainOptions): StorageScope {
+ switch (options.scope) {
@ -48,7 +48,7 @@ index b522e75..5205e2b 100644
+
toJSON(): object {
diff --git a/src/vs/workbench/services/banner/browser/bannerService.ts b/src/vs/workbench/services/banner/browser/bannerService.ts
index d8560ce..23f5c0c 100644
index 9c1ab0d..688b1dc 100644
--- a/src/vs/workbench/services/banner/browser/bannerService.ts
+++ b/src/vs/workbench/services/banner/browser/bannerService.ts
@@ -10,2 +10,3 @@ import { ILinkDescriptor } from 'vs/platform/opener/browser/link';
@ -58,4 +58,4 @@ index d8560ce..23f5c0c 100644
@@ -18,2 +19,3 @@ export interface IBannerItem {
readonly onClose?: () => void;
+ readonly neverShowAgain?: INeverShowAgainOptions;
readonly disableCloseAction?: boolean;
readonly closeLabel?: string;

View File

@ -1,10 +1,16 @@
diff --git a/build/gulpfile.reh.js b/build/gulpfile.reh.js
index 595d0ce..2e94d99 100644
index c2b81d0..2e94d99 100644
--- a/build/gulpfile.reh.js
+++ b/build/gulpfile.reh.js
@@ -375,10 +375,2 @@ function packageTask(type, platform, arch, sourceFolderName, destinationFolderNa
@@ -375,16 +375,2 @@ function packageTask(type, platform, arch, sourceFolderName, destinationFolderNa
- if (platform === 'linux' || platform === 'alpine') {
- if (platform === 'linux' && process.env['VSCODE_NODE_GLIBC'] === '-glibc-2.17') {
- result = es.merge(result,
- gulp.src(`resources/server/bin/helpers/check-requirements-linux-legacy.sh`, { base: '.' })
- .pipe(rename(`bin/helpers/check-requirements.sh`))
- .pipe(util.setExecutableBit())
- );
- } else if (platform === 'linux' || platform === 'alpine') {
- result = es.merge(result,
- gulp.src(`resources/server/bin/helpers/check-requirements-linux.sh`, { base: '.' })
- .pipe(rename(`bin/helpers/check-requirements.sh`))
@ -14,25 +20,25 @@ index 595d0ce..2e94d99 100644
-
return result.pipe(vfs.dest(destination));
diff --git a/remote/.yarnrc b/remote/.yarnrc
index cac528f..0d11e36 100644
index 4e7208c..f7304bc 100644
--- a/remote/.yarnrc
+++ b/remote/.yarnrc
@@ -1,3 +1,3 @@
disturl "https://nodejs.org/dist"
-target "18.17.1"
-target "18.18.2"
+target "16.20.2"
ms_build_id "255375"
ms_build_id "256117"
diff --git a/remote/package.json b/remote/package.json
index 1d341b0..751c326 100644
index 974450e..513856f 100644
--- a/remote/package.json
+++ b/remote/package.json
@@ -31,3 +31,3 @@
"native-watchdog": "^1.4.1",
- "node-pty": "1.1.0-beta6",
- "node-pty": "1.1.0-beta11",
+ "node-pty": "1.1.0-beta4",
"tas-client-umd": "0.1.8",
diff --git a/remote/yarn.lock b/remote/yarn.lock
index 5fdbd09..74dc7c6 100644
index d62eb4b..f175b85 100644
--- a/remote/yarn.lock
+++ b/remote/yarn.lock
@@ -391,2 +391,7 @@ ms@2.1.2:
@ -50,10 +56,10 @@ index 5fdbd09..74dc7c6 100644
version "7.1.0"
@@ -433,8 +438,8 @@ node-gyp-build@^4.3.0:
-node-pty@1.1.0-beta6:
- version "1.1.0-beta6"
- resolved "https://registry.yarnpkg.com/node-pty/-/node-pty-1.1.0-beta6.tgz#8b27ce40268e313868925e1b46f2af98cc677881"
- integrity sha512-ZcuPz5wIbfF4rebVv8sl+nf2Cn5dVMqlEl9PtabCt4uIffGDnovOpmwh16Oh/MThrwSmeJL6gBwu6lIbBtW7DQ==
-node-pty@1.1.0-beta11:
- version "1.1.0-beta11"
- resolved "https://registry.yarnpkg.com/node-pty/-/node-pty-1.1.0-beta11.tgz#909d5dd8f9aa2a7857e7b632fd4d2d4768bdf69f"
- integrity sha512-vTjF+VrvSCfPDILUkIT+YrG1Fdn06/eBRS2fc9a3JzYAvknMB1Ip8aoJhxl8hNpjWAbprmCEiV91mlfNpCD+GQ==
+node-pty@1.1.0-beta4:
+ version "1.1.0-beta4"
+ resolved "https://registry.npmjs.org/node-pty/-/node-pty-1.1.0-beta4.tgz#ee74d909c9f422ffc7f675e1092529673f8906ec"
@ -62,30 +68,3 @@ index 5fdbd09..74dc7c6 100644
- node-addon-api "^7.1.0"
+ nan "^2.17.0"
diff --git a/resources/server/bin/code-server-linux.sh b/resources/server/bin/code-server-linux.sh
index e3d96bd..3df32df 100644
--- a/resources/server/bin/code-server-linux.sh
+++ b/resources/server/bin/code-server-linux.sh
@@ -11,22 +11,2 @@ ROOT="$(dirname "$(dirname "$(readlink -f "$0")")")"
-# Do not remove this check.
-# Provides a way to skip the server requirements check from
-# outside the install flow. A system process can create this
-# file before the server is downloaded and installed.
-skip_check=0
-if [ -f "/tmp/vscode-skip-server-requirements-check" ]; then
- echo "!!! WARNING: Skipping server pre-requisite check !!!"
- echo "!!! Server stability is not guaranteed. Proceed at your own risk. !!!"
- skip_check=1
-fi
-
-# Check platform requirements
-if [ "$(echo "$@" | grep -c -- "--skip-requirements-check")" -eq 0 ] && [ $skip_check -eq 0 ]; then
- $ROOT/bin/helpers/check-requirements.sh
- exit_code=$?
- if [ $exit_code -ne 0 ]; then
- exit $exit_code
- fi
-fi
-
"$ROOT/node" ${INSPECT:-} "$ROOT/out/server-main.js" "$@"

View File

@ -1,5 +1,5 @@
diff --git a/build/gulpfile.reh.js b/build/gulpfile.reh.js
index df18cf0..23acd46 100644
index c2b81d0..4972cec 100644
--- a/build/gulpfile.reh.js
+++ b/build/gulpfile.reh.js
@@ -46,2 +46,3 @@ const BUILD_TARGETS = [
@ -15,7 +15,7 @@ index 6f8144b..4479ae7 100644
+ { platform: 'linux', arch: 'ppc64le' },
];
diff --git a/build/gulpfile.vscode.js b/build/gulpfile.vscode.js
index bfd5c89..b66af36 100644
index e1507e0..997b553 100644
--- a/build/gulpfile.vscode.js
+++ b/build/gulpfile.vscode.js
@@ -431,2 +431,3 @@ const BUILD_TARGETS = [
@ -113,45 +113,45 @@ index e97485e..356027a 100644
+ return ['amd64', 'armhf', 'arm64', 'ppc64le'].includes(s);
}
diff --git a/cli/src/update_service.rs b/cli/src/update_service.rs
index d218e4a..d97e736 100644
index 4bec13d..5aa944d 100644
--- a/cli/src/update_service.rs
+++ b/cli/src/update_service.rs
@@ -213,2 +213,3 @@ pub enum Platform {
LinuxARM32,
+ LinuxPPC64LE,
@@ -216,2 +216,3 @@ pub enum Platform {
LinuxARM32Legacy,
+ LinuxPPC64LE
DarwinX64,
@@ -226,2 +227,3 @@ impl Platform {
@@ -229,2 +230,3 @@ impl Platform {
Platform::LinuxARM32 => Some("linux-armhf".to_owned()),
+ Platform::LinuxPPC64LE => Some("linux-ppc64le".to_owned()),
Platform::DarwinX64 => Some("darwin".to_owned()),
@@ -241,2 +243,3 @@ impl Platform {
Platform::LinuxARM32 => "server-linux-armhf",
@@ -247,2 +249,3 @@ impl Platform {
Platform::LinuxARM32Legacy => "server-linux-legacy-armhf",
+ Platform::LinuxPPC64LE => "server-linux-ppc64le",
Platform::DarwinX64 => "server-darwin",
@@ -257,2 +260,3 @@ impl Platform {
Platform::LinuxARM32 => "cli-linux-armhf",
@@ -266,2 +269,3 @@ impl Platform {
Platform::LinuxARM32Legacy => "cli-linux-armhf",
+ Platform::LinuxPPC64LE => "cli-linux-ppc64le",
Platform::DarwinX64 => "cli-darwin-x64",
@@ -289,2 +293,4 @@ impl Platform {
@@ -298,2 +302,4 @@ impl Platform {
Some(Platform::LinuxARM64)
+ } else if cfg!(all(target_os = "linux", target_arch = "ppc64le")) {
+ Some(Platform::LinuxPPC64LE)
} else if cfg!(all(target_os = "macos", target_arch = "x86_64")) {
@@ -313,2 +319,3 @@ impl fmt::Display for Platform {
Platform::LinuxARM32 => "LinuxARM32",
@@ -325,2 +331,3 @@ impl fmt::Display for Platform {
Platform::LinuxARM32Legacy => "LinuxARM32Legacy",
+ Platform::LinuxPPC64LE => "LinuxPPC64LE",
Platform::DarwinX64 => "DarwinX64",
diff --git a/cli/src/util/prereqs.rs b/cli/src/util/prereqs.rs
index 4f2a6ad..ded331b 100644
index 20a5bc9..1669bf7 100644
--- a/cli/src/util/prereqs.rs
+++ b/cli/src/util/prereqs.rs
@@ -74,2 +74,4 @@ impl PreReqChecker {
Platform::LinuxARM32
+ } else if cfg!(target_arch = "ppc64le") {
+ Platform::LinuxPPC64LE
} else {
@@ -75,2 +75,4 @@ impl PreReqChecker {
Platform::LinuxARM32
+ } else if cfg!(target_arch = "ppc64le") {
+ Platform::LinuxPPC64LE
} else {
diff --git a/src/main.js b/src/main.js
index de5c7df..8248089 100644
index 90de17b..80f5c47 100644
--- a/src/main.js
+++ b/src/main.js
@@ -435,2 +435,3 @@ function configureCrashReporter() {
@ -159,28 +159,28 @@ index de5c7df..8248089 100644
+
submitURL = appCenter['linux-x64'];
diff --git a/src/vs/platform/extensionManagement/common/extensionManagement.ts b/src/vs/platform/extensionManagement/common/extensionManagement.ts
index 15907ec..a3c41d0 100644
index 9dae82e..64ad08b 100644
--- a/src/vs/platform/extensionManagement/common/extensionManagement.ts
+++ b/src/vs/platform/extensionManagement/common/extensionManagement.ts
@@ -30,2 +30,3 @@ export function TargetPlatformToString(targetPlatform: TargetPlatform) {
@@ -35,2 +35,3 @@ export function TargetPlatformToString(targetPlatform: TargetPlatform) {
case TargetPlatform.LINUX_ARMHF: return 'Linux ARM';
+ case TargetPlatform.LINUX_PPC64LE: return 'Linux PPC64LE';
@@ -53,2 +54,3 @@ export function toTargetPlatform(targetPlatform: string): TargetPlatform {
@@ -58,2 +59,3 @@ export function toTargetPlatform(targetPlatform: string): TargetPlatform {
case TargetPlatform.LINUX_ARMHF: return TargetPlatform.LINUX_ARMHF;
+ case TargetPlatform.LINUX_PPC64LE: return TargetPlatform.LINUX_PPC64LE;
@@ -88,2 +90,5 @@ export function getTargetPlatform(platform: Platform | 'alpine', arch: string |
@@ -93,2 +95,5 @@ export function getTargetPlatform(platform: Platform | 'alpine', arch: string |
}
+ if (arch === 'ppc64le') {
+ return TargetPlatform.LINUX_PPC64LE;
+ }
return TargetPlatform.UNKNOWN;
diff --git a/src/vs/platform/extensions/common/extensions.ts b/src/vs/platform/extensions/common/extensions.ts
index 413c1db..e61e771 100644
index 331aba1..57e01f2 100644
--- a/src/vs/platform/extensions/common/extensions.ts
+++ b/src/vs/platform/extensions/common/extensions.ts
@@ -303,2 +303,3 @@ export const enum TargetPlatform {
@@ -305,2 +305,3 @@ export const enum TargetPlatform {
LINUX_ARMHF = 'linux-armhf',
+ LINUX_PPC64LE = 'linux-ppc64le',

View File

@ -1,9 +1,9 @@
diff --git a/src/vs/platform/update/electron-main/updateService.win32.ts b/src/vs/platform/update/electron-main/updateService.win32.ts
index 99bf807..b5b4333 100644
index 4c49a75..7840d2a 100644
--- a/src/vs/platform/update/electron-main/updateService.win32.ts
+++ b/src/vs/platform/update/electron-main/updateService.win32.ts
@@ -156,3 +156,3 @@ export class Win32UpdateService extends AbstractUpdateService implements IRelaun
}).then(packagePath => {
- const fastUpdatesEnabled = this.configurationService.getValue('update.enableWindowsBackgroundUpdates');
+ const fastUpdatesEnabled = getUpdateType() == UpdateType.Setup && this.configurationService.getValue('update.enableWindowsBackgroundUpdates');
@@ -270,3 +270,3 @@ export class Win32UpdateService extends AbstractUpdateService implements IRelaun
- const fastUpdatesEnabled = this.configurationService.getValue('update.enableWindowsBackgroundUpdates');
+ const fastUpdatesEnabled = getUpdateType() == UpdateType.Setup && this.configurationService.getValue('update.enableWindowsBackgroundUpdates');
const update: IUpdate = { version: 'unknown', productVersion: 'unknown' };

View File

@ -33,20 +33,3 @@ index ebc4749..18fd732 100644
+export function isHostedGitHubEnterprise(_uri: Uri): boolean {
+ return false;
}
diff --git a/src/vs/workbench/services/authentication/browser/authenticationService.ts b/src/vs/workbench/services/authentication/browser/authenticationService.ts
index ab9c569..1674eaa 100644
--- a/src/vs/workbench/services/authentication/browser/authenticationService.ts
+++ b/src/vs/workbench/services/authentication/browser/authenticationService.ts
@@ -290,12 +290,2 @@ export class AuthenticationService extends Disposable implements IAuthentication
this._authenticationProviderDisposables.deleteAndDispose(id);
-
- if (!this._authenticationProviders.size) {
- placeholderMenuItem = MenuRegistry.appendMenuItem(MenuId.AccountsContext, {
- command: {
- id: 'noAuthenticationProviders',
- title: nls.localize('loading', "Loading..."),
- precondition: ContextKeyExpr.false()
- },
- });
- }
}
diff --git a/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts b/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts
index fa11076..588cba5 100644
index 89ea0e5..c2b1f32 100644
--- a/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts
+++ b/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts
@@ -359,3 +359,3 @@ export class Extension implements IExtension {
@@ -404,3 +404,3 @@ export class Extension implements IExtension {
return Promise.resolve(`# ${this.displayName || this.name}
**Notice:** This extension is bundled with Visual Studio Code. It can be disabled but not uninstalled.
## Features
@@ -392,3 +392,3 @@ ${this.description}
@@ -442,3 +442,3 @@ ${this.description}
if (this.type === ExtensionType.System) {
- return Promise.resolve('Please check the [VS Code Release Notes](command:update.showCurrentReleaseNotes) for changes to the built-in extensions.');
+ return Promise.resolve('Please check the [VSCodium Release Notes](command:update.showCurrentReleaseNotes) for changes to the built-in extensions.');
}
@@ -1109,3 +1109,3 @@ export class ExtensionsWorkbenchService extends Disposable implements IExtension
if (!canRemoveRunningExtension && isSameExtensionRunning && !runningExtension.isUnderDevelopment) {
- return nls.localize('postUninstallTooltip', "Please reload Visual Studio Code to complete the uninstallation of this extension.");
+ return nls.localize('postUninstallTooltip', "Please reload VSCodium to complete the uninstallation of this extension.");
}
@@ -1129,3 +1129,3 @@ export class ExtensionsWorkbenchService extends Disposable implements IExtension
if (!runningExtension.isUnderDevelopment && (extension.version !== runningExtension.version || extension.local.targetPlatform !== runningExtension.targetPlatform)) {
- return nls.localize('postUpdateTooltip', "Please reload Visual Studio Code to enable the updated extension.");
+ return nls.localize('postUpdateTooltip', "Please reload VSCodium to enable the updated extension.");
}
@@ -1137,3 +1137,3 @@ export class ExtensionsWorkbenchService extends Disposable implements IExtension
if (runningExtensionServer === this.extensionManagementServerService.remoteExtensionManagementServer && this.extensionManifestPropertiesService.prefersExecuteOnUI(extension.local.manifest) && extensionInOtherServer.server === this.extensionManagementServerService.localExtensionManagementServer) {
- return nls.localize('enable locally', "Please reload Visual Studio Code to enable this extension locally.");
+ return nls.localize('enable locally', "Please reload VSCodium to enable this extension locally.");
}
@@ -1142,3 +1142,3 @@ export class ExtensionsWorkbenchService extends Disposable implements IExtension
if (runningExtensionServer === this.extensionManagementServerService.localExtensionManagementServer && this.extensionManifestPropertiesService.prefersExecuteOnWorkspace(extension.local.manifest) && extensionInOtherServer.server === this.extensionManagementServerService.remoteExtensionManagementServer) {
- return nls.localize('enable remote', "Please reload Visual Studio Code to enable this extension in {0}.", this.extensionManagementServerService.remoteExtensionManagementServer?.label);
+ return nls.localize('enable remote', "Please reload VSCodium to enable this extension in {0}.", this.extensionManagementServerService.remoteExtensionManagementServer?.label);
}
@@ -1152,3 +1152,3 @@ export class ExtensionsWorkbenchService extends Disposable implements IExtension
if (this.extensionManifestPropertiesService.prefersExecuteOnUI(extension.local.manifest)) {
- return nls.localize('postEnableTooltip', "Please reload Visual Studio Code to enable this extension.");
+ return nls.localize('postEnableTooltip', "Please reload VSCodium to enable this extension.");
}
@@ -1158,3 +1158,3 @@ export class ExtensionsWorkbenchService extends Disposable implements IExtension
if (this.extensionManifestPropertiesService.prefersExecuteOnWorkspace(extension.local.manifest)) {
- return nls.localize('postEnableTooltip', "Please reload Visual Studio Code to enable this extension.");
+ return nls.localize('postEnableTooltip', "Please reload VSCodium to enable this extension.");
}
@@ -1165,3 +1165,3 @@ export class ExtensionsWorkbenchService extends Disposable implements IExtension
if (isSameExtensionRunning) {
- return nls.localize('postDisableTooltip', "Please reload Visual Studio Code to disable this extension.");
+ return nls.localize('postDisableTooltip', "Please reload VSCodium to disable this extension.");
}
@@ -1174,3 +1174,3 @@ export class ExtensionsWorkbenchService extends Disposable implements IExtension
if (isEnabled && !this.extensionService.canAddExtension(toExtensionDescription(extension.local))) {
- return nls.localize('postEnableTooltip', "Please reload Visual Studio Code to enable this extension.");
+ return nls.localize('postEnableTooltip', "Please reload VSCodium to enable this extension.");
}
@@ -1182,3 +1182,3 @@ export class ExtensionsWorkbenchService extends Disposable implements IExtension
if (extensionInOtherServer && extensionInOtherServer.local && this.extensionEnablementService.isEnabled(extensionInOtherServer.local)) {
- return nls.localize('postEnableTooltip', "Please reload Visual Studio Code to enable this extension.");
+ return nls.localize('postEnableTooltip', "Please reload VSCodium to enable this extension.");
}
@@ -404,3 +404,3 @@ export class Extension implements IExtension {
return Promise.resolve(`# ${this.displayName || this.name}
-**Notice:** This extension is bundled with Visual Studio Code. It can be disabled but not uninstalled.
+**Notice:** This extension is bundled with VSCodium. It can be disabled but not uninstalled.
## Features